/***************************************************************************
 *   Copyright (C) 2009 by QEVEN Team                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 **************************************************************************/

#include "video_analyzer.h"

namespace utils {

   /**
        * Constructor. Recibe la direccion del archivo de video (QString)
        * @param video_file  la ruta al archivo(QString)
        * @param bmplayer    la ruta al mplayer (QString)
        */
   Video_Analyzer::Video_Analyzer( QString video_file, QString bmplayer )
   {
      m_video_name = "";
      m_video_directory = "";
      m_video_full_path = video_file;
      m_video_bitrate = 0;
      m_audio_bitrate = 0;
      m_video_with = 0;
      m_video_height = 0;
      m_video_aspect = 0;
      MPlayer = bmplayer;

      m_read_video_process = new QProcess;
      read_Video( m_video_full_path );

      QByteArray output = m_read_video_process->readAllStandardOutput();
      m_video_info = output.constData();
   }
   /**
    * Destructor
    */
   Video_Analyzer::~Video_Analyzer()
   {
      delete m_read_video_process;
   }

   /**
    * Este metodo es llamado directamente desde el constructor. Recibe
    * la ruta al archivo de video a analizar, levanta un proceso del mplayer
    * con el parametro -identify y espera que finalice el proceso.
    * El proceso del mplayer lee solo dos frames del video, a partir de ahi
    * se obtiene toda la informacion en los demás métodos.
    *
    * @param video_file La ruta al video a analizar (QString)    *
    */
   void Video_Analyzer::read_Video( QString video_file )
   {
      QString program = MPlayer;
      QStringList arguments;
      arguments <<
            "-identify" <<
            video_file <<
            "-ao" <<
            "null" <<
            "-vo" <<
            "null" <<
            "-frames" <<
            "1";

      m_read_video_process->start(program,arguments);
      m_read_video_process->waitForFinished();
   }

   /**
    * Este metodo devuelve el nombre del video
    * a partir de la ruta recibida.
     * Ejemplo: recibe /home/pepe/video.avi
    * devuelve: video.avi
    *
    * @return m_video_name  El nombre del video.
    */
   QString Video_Analyzer::get_Video_Name()
   {
      // Con expresiones regulares usando mencoder:
      /* QRegExp ID_FILENAME("ID_FILENAME=( |[?]*_*-*ñ*|Ñ*|[a-z]|[A-Z]|[0-9])*(.mp4|.MP4|.mov|.MOV|.wmv|.WMV|.avi|.AVI|.mpg|.MPG|.mpeg|.MPEG|.rm|.RM|.rmvb|.RMVB|.dat|.DAT)"); //Expresion Regular que reconoce el nombre del archivo.extension

        ID_FILENAME.indexIn(m_video_info); //procesamos la info del video
        QString temp_file_name= ID_FILENAME.capturedTexts().front();


        QRegExp NAME("(.*| |[?]*_*-*ñ*|Ñ*|[a-z]|[A-Z]|[0-9])*(.mp4|.MP4|.mov|.MOV|.wmv|.WMV|.avi|.AVI|.mpg|.MPG|.mpeg|.MPEG|.rm|.RM|.rmvb|.RMVB|.dat|.DAT)");

        NAME.indexIn(temp_file_name);
        m_file_name = NAME.capturedTexts().front();*/

      //De la otra forma:
      QStringList aux_name =  m_video_full_path.split( "/" );
      m_video_name = aux_name.last();

      return m_video_name;
   }

   /**
    * Este metodo devuelve el directorio del video, sin el nombre del mismo.
    * Ejemplo(Linux): en el constructor se recibe /home/pepe/myvideo/video.avi
    * Ejemplo(Win32): en el constructor recibe c:/Document and Settings/pepe/Desktop/video.avi
    * Devuelve(Linux): /home/pepe/myvideo/
    * Devuelve(Win32): c:\Document and Settings\pepe\Desktop\
    *
    * @return m_video_directory Directorio donde está el video.
    */
   QString Video_Analyzer::get_Video_Directory()
   {

#ifdef Q_OS_LINUX
      QStringList path_aux = m_video_full_path.split( "/" );
      path_aux.removeLast();
      m_video_directory= path_aux.join( "/" ).append( "/" );
#endif

#ifdef Q_OS_WIN32
      QStringList path_aux = m_video_full_path.split( "/" );
      path_aux.removeLast();
      m_video_directory= path_aux.join( "\\" ).append( "\\" );
#endif

      return m_video_directory;
   }

   /**
    * Este metodo devuelve el bitrate de video del archivo original, o sea
    * cuando se agrega un nuevo video a la lista se obtiene su bitrate original.
    *
    * @return m_video_bitrate El bitrate de video. (int)
    */
   int Video_Analyzer::get_Video_Bitrate()
   {
      //Investigar en la ayuda del mencoder
      QRegExp ID_VIDEO_BITRATE( "ID_VIDEO_BITRATE=[0-9]{1,10}");
      ID_VIDEO_BITRATE.indexIn( m_video_info );
      QRegExp VIDEO_BITRATE("[0-9]{1,10}");
      VIDEO_BITRATE.indexIn(ID_VIDEO_BITRATE.capturedTexts().front());
      m_video_bitrate = (VIDEO_BITRATE.capturedTexts().front().toInt())/1000;

      if(m_video_bitrate>=500)
        return m_video_bitrate;
      else
         return 1150;

   }

   /**
    * Este metodo devuelve el bitrate de audio del archivo original, o sea
    * cuando se agrega un nuevo video a la lista se obtiene su bitrate original.
    *
    * @return m_audio_bitrate El bitrate de audio. (int)
    */
   int Video_Analyzer::get_Audio_Bitrate()
   {
      QRegExp ID_AUDIO_BITRATE( "ID_AUDIO_BITRATE=[0-9]{1,10}");
      ID_AUDIO_BITRATE.indexIn( m_video_info );
      QRegExp AUDIO_BITRATE("[0-9]{1,10}");
      AUDIO_BITRATE.indexIn(ID_AUDIO_BITRATE.capturedTexts().front());
      m_audio_bitrate = (AUDIO_BITRATE.capturedTexts().front().toInt())/1000;

      if(m_audio_bitrate>=32)
        return m_audio_bitrate;
      else
        return 128;
   }

   /**
    * Este metodo devuelve la duracion del video en segundos.
    *
    * @return m_duration  La duracion del vídeo. (int)
    */
   int Video_Analyzer::get_Duration()
   {
      QRegExp ID_LENGTH( "ID_LENGTH=[0-9]{1,10}" );
      ID_LENGTH.indexIn( m_video_info ); // procesamos la cadena usando nuestra expresion

      QRegExp SECONDS( "[0-9]{1,10}" ); // creamos una nueva expresion regular
      // esta vez solo tomaremos de los resultados
      // de la anterior solamente los numeros,
      // eliminando la cadena ID_LENGTH=

      SECONDS.indexIn( ID_LENGTH.capturedTexts().front() );  // evaluamos nuestra exp en la cadena
      m_duration = SECONDS.capturedTexts().front().toInt();

      return m_duration;
   }

   /**
    * Este metodo devuelve el directorio del video original, incluyendo el nombre del video.
    * Ejemplo: /home/pepe/myvideo/video.avi . Esto permite que se mantenga una referencia
    * completa a la ruta del archivo de video aunque se procesen en otros métodos el nombre y la ruta
    * por separado.
    *
    * @return m_video_full_path Ruta completa al video (QString)
    */
   QString Video_Analyzer::get_Video_Full_Path()
   {
      return m_video_full_path;
   }

   /**
    * Retorna el ancho del video original
    * @return m_video_width  (int) Ancho del video.
     */
   int Video_Analyzer::get_Video_Width()
   {
      QRegExp ID_VIDEO_WIDTH( "ID_VIDEO_WIDTH=[0-9]{1,10}");
      ID_VIDEO_WIDTH.indexIn( m_video_info );
      QRegExp VIDEO_WIDTH("[0-9]{1,10}");
      VIDEO_WIDTH.indexIn(ID_VIDEO_WIDTH.capturedTexts().front());
      m_video_with = VIDEO_WIDTH.capturedTexts().front().toInt();

      return m_video_with;
   }

   /**
    * Retorna el alto del video original
    * @return m_video_height  (int) Ancho del video.
     */
   int Video_Analyzer::get_Video_Height()
   {
      QRegExp ID_VIDEO_HEIGHT( "ID_VIDEO_HEIGHT=[0-9]{1,10}");
      ID_VIDEO_HEIGHT.indexIn( m_video_info );
      QRegExp VIDEO_HEIGHT("[0-9]{1,10}");
      VIDEO_HEIGHT.indexIn(ID_VIDEO_HEIGHT.capturedTexts().front());
      m_video_height = VIDEO_HEIGHT.capturedTexts().front().toInt();
      return m_video_height;
   }

   /**
    * Retorna los frames por segundo del video original.
    * 25 fps es PAL, 29 a 30 es NTSC.
    * @return m_fps  (int) Frames por segundo
     */
   float Video_Analyzer::get_Fps()
   {
      /**
          OJO HAY QUE ARREGLAR LA EXP REGULAR PARA QUE
          COJA LOS DECIMALES TAMBIEN, EJEMPLO 29.33.
          POR AHORA SOLO DEVUELVE ENTEROS.
          */
      QRegExp ID_VIDEO_FPS( "ID_VIDEO_FPS=[0-9]{1,10}");
      ID_VIDEO_FPS.indexIn( m_video_info );
      QRegExp VIDEO_FPS("[0-9]{1,10}");
      VIDEO_FPS.indexIn(ID_VIDEO_FPS.capturedTexts().front());
      m_fps = VIDEO_FPS.capturedTexts().front().toFloat();
      return m_fps;
   }

   float Video_Analyzer::get_Video_Aspect()
   {
      QRegExp ID_VIDEO_ASPECT( "ID_VIDEO_ASPECT=[0-9]{1,10}");
      ID_VIDEO_ASPECT.indexIn( m_video_info );
      QRegExp VIDEO_ASPECT("[0-9]{1,10}");
      VIDEO_ASPECT.indexIn(ID_VIDEO_ASPECT.capturedTexts().last());
      m_video_aspect = VIDEO_ASPECT.capturedTexts().front().toFloat();
      return m_video_aspect;

   }

   int Video_Analyzer::get_aid()
   {
      QRegExp ID_AUDIO_ID( "ID_AUDIO_ID=[0-9]");
      ID_AUDIO_ID.indexIn( m_video_info );
      QRegExp AID("[0-9]");
      AID.indexIn(ID_AUDIO_ID.capturedTexts().last());
      m_aid = AID.capturedTexts().front().toFloat();
      return m_aid;
   }
}
