/***************************************************************************
 *   Copyright (C) 2009 by QEVEN Team                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 **************************************************************************/

#include "video_converter.h"
#include <QObject>
#include <iostream>

namespace utils {

   /**
     * Constructor que recibe como parametro de entrada el directorio
     * donde se guardaran los archivos convertidos.
     *
     * @param output_dir (QString) Directorio destino para la conversion
     */
   Video_Converter::Video_Converter( QString output_dir,
                                     QObject *parent ) :
   QObject(parent)
   {
      m_output_directory = output_dir;
      m_command = "";
      m_output_name = "";
      mencoder_process = new QProcess;
      connect( mencoder_process, SIGNAL( readyReadStandardOutput() ),
               this, SLOT( Read_Output_Info() ) ); //cada vez que hay info disponible en la salida estandar, se lee a traves del SLOT indicado.
      connect( mencoder_process, SIGNAL( finished( int ) ),
               this, SLOT( Finished_Process() ) ); //cuando el proceso finaliza, se ejecuta el SLOT encargado de notificarlo.
   }

   /**
    * Constructor por defecto. No recibe parametros.
    */
   Video_Converter::Video_Converter( QObject *parent ) :
         QObject(parent)
   {
      m_output_directory = "";
      m_command = "";
      mencoder_process = new QProcess;
      connect( mencoder_process, SIGNAL( readyReadStandardOutput() ),
               this, SLOT( Read_Output_Info() ) );
      connect( mencoder_process, SIGNAL( finished( int ) ),
               this, SLOT( Finished_Process() ) );
   }

   /**
    * Destructor
     */
   Video_Converter::~Video_Converter()
   {
      delete mencoder_process;
   }

   /**
     * Funcion. Arranca el proceso del mencoder, pasandole
     * como parametros el nombre del archivo final y el comando
     * con las opciones de la conversion
     * el parametro rmencoder contiene la ruta segun la plataforma real del mencoder
     *
     * @param output_name (QString) Nombre del archivo de salida, Ejemplo: [VCD]pepe.mpg
     * @param command (QString) Comando para con las opciones para convertir el video.
     * @param rmencoder (QString)  Ruta al mencoder
     */
   void Video_Converter::convert( QString output_name, QString command , QString rmencoder)
   {
      QString m_option = command;
      m_output_name = output_name;
      m_command = rmencoder;
      m_command.append( " ").append( m_option) .append( " -o \"").append(m_output_directory);
      m_command.append("/"+output_name).append( "\"");


      std::cout<<m_command.toStdString();
      mencoder_process->start( m_command );
   }

   /**
     * SLOT. Lee la salida estandar del mencoder,
     * filtra la informacion y emite dos signals:
     * signal Time_Remaining(const QString &) : tiempo restante para finalizar la conversion del archivo actual
     * signal Percent_Completed(const int &) : porciento realizado de la conversion.
     * Es privado de la clase.
     */
   void Video_Converter::Read_Output_Info()
   {
      QByteArray info = mencoder_process->readAllStandardOutput();
      QString str = info.constData();

      QRegExp time_exp( "[0-9]{1,3}min" );
      time_exp.indexIn( str );

      QString time_remaining = time_exp.capturedTexts().front();

      QRegExp percent_exp( "[0-9]{1,3}%" ); // defino un expresion regular para
      // capturar cualquier numero de 3 cifras
      // que termine en %
      percent_exp.indexIn( str ); // procesamos la cadena usando nuestra expresion

      QRegExp int_percent_exp( "[0-9]{1,3}" ); // creamos una nueva expresion regular
      // esta vez solo tomaremos de los resultados
      // de la anterior solamente los numeros,
      // eliminando el %
      int_percent_exp.indexIn( percent_exp.capturedTexts().front() ); // evaluamos nuestra exp en la cadena

      int percent = int_percent_exp.capturedTexts().front().toInt();

      emit Time_Remaining( time_remaining );
      emit Percent_Completed( percent );
   }

   /**
     * SLOT Es el encargado de emitir la signal Process_Has_Finished, que indica que
     * se termino de ejecutar el proceso de mencoder. Es privado de la clase.
     */
   void Video_Converter::Finished_Process()
   {
      emit Process_Has_Finished();
   }

   /**
     * Funcion. Permite establecer el directorio de salida, donde se guardara
     * el archivo final.
     */
   void Video_Converter::set_Output_Dir( QString output_dir )
   {
      m_output_directory = output_dir;
   }

   /**
     * SLOT. Detiene el proceso de mencoder.
     * Emite la signal Process_Has_Finished(), que indica
     * que el proceso ha terminado. Se ejecuta cuando se termina
     * de convertir la lista
     */
   void Video_Converter::Stop_Process()
   {
#ifdef Q_OS_LINUX
      // change de command to execute
      this->m_command = "kill ";
      this->m_command.append( QString::number( this->mencoder_process->pid() ) );
      // Parar las instancias de mplayer que se estan ejecutando. 2008-11-18 12:44:04.
      this->mencoder_process->execute( "killall -s KILL mencoder" );
      //this->mencoder_process->execute( m_command );
#endif
#ifdef Q_OS_WIN32
      this->mencoder_process->kill();
#endif

      emit Process_Has_Finished();
   }

   /**
     *
     *
     */
   void Video_Converter::Cancel_Process()
   {


#ifdef Q_OS_LINUX
      // change de command to execute
      this->m_command = "kill ";
      this->m_command.append( QString::number( this->mencoder_process->pid() ) );
      // Parar las instancias de mplayer que se estan ejecutando. 2008-11-18 12:44:04.
      this->mencoder_process->execute( "killall -s KILL mencoder" );
      //this->mencoder_process->execute( m_command );
#endif
#ifdef Q_OS_WIN32
      this->mencoder_process->kill();
#endif
   }

   string Video_Converter::get_OutPut_Dir()
   {
      return m_output_directory.toStdString();
   }

   string Video_Converter::get_OutPut_Name()
   {
      return m_output_name.toStdString();
   }

   string Video_Converter::get_Output_File()
   {
      string output_file = get_OutPut_Dir () +"/" + get_OutPut_Name () ;
      return output_file;
   }

}
