/***************************************************************************
 *   Copyright (C) 2009 by QEVEN Team                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 **************************************************************************/
#include "video_item.h"
namespace video {

   /**
    * Este es el constructor vacío.
    * Se inicializan todos los atributos con sus valores
    * por defecto.
    */
   Video_Item::Video_Item()
   {
      // por defecto se crea un Video_Item con
      // formato vcd, se establace el vbitrare y abitrate correctos
      // para ese tipo de formato
      m_video_filename = "";
      m_video_path = "";
      m_video_bitrate = 1152;
      m_audio_bitrate = 224;
      m_video_duration = 0;
      m_subtitles_font = "";
      m_subtitles = "";
      m_subtitles_scale = 3;
      m_has_Subtitles = false;
      m_video_aspect = ":autoaspect";
      m_format = vcd;
      m_command = "";
      m_video_width = 0;
      m_video_height = 0;
      m_video_height_original = 0;
      m_video_width_original = 0;
      m_fps = 0;
   }

   /**
    * Constructor con parámetros.
    * Permite construir un elemento de vídeo
    * a partir de una serie de parámetros.
    * En este constructor no se tienen en cuenta los subtitulos
    * ni el aspecto de la película, estos se inicializan vacíos por defecto.
    *
    * @param filename (QString) Nombre del video, Ejemplo: pepe.avi
    * @param filepath (QString) Ruta al archivo, Ejemplo: /home/pepe/video/
    * @param video_bitrate (int) Bitrate del video original
    * @param audio_bitrate (int) Bitrate de audio original
    * @param duration (int) Duración del vídeo en segundos.
    * @param format (e_video_format) Formato del video. Es un enum.@see e_video_format    *
    */
   Video_Item::Video_Item( QString filename,
                           QString filepath,
                           int video_bitrate,
                           int audio_bitrate,
                           int duration,
                           e_video_format format )
   {
      m_video_filename = filename;
      m_video_path = filepath;
      m_video_bitrate = video_bitrate;
      m_audio_bitrate = audio_bitrate;     
      m_video_duration = duration;
      m_subtitles_font = "";
      m_subtitles = "";
      m_subtitles_scale = 3;

      m_video_aspect = ":autoaspect";
      m_has_Subtitles = false;
      m_format = format;
      m_command = "";
      m_video_width = 0;
      m_video_height = 0;
      m_video_height_original = 0;
      m_video_width_original = 0;
      m_fps = 0;
      if(format== vcd)
         m_resolution = 1;
      else if(format ==  svcd)
         m_resolution = 2;
      else if(format == dvd)
         m_resolution = 3;
      else
         m_resolution = 0;
   }

   /**
    * Constructor con parámetros.
    * Permite construir un elemento de vídeo
    * a partir de una serie de parámetros. Recibe todos los
    * parámetros de un archivo de vídeo, incluyendo subtitulos, fuente,
    * tamaño de los subtitulos, aspecto, etc.
    *
    * @param filename (QString) Nombre del video, Ejemplo: pepe.avi
    * @param filepath (QString) Ruta al archivo, Ejemplo: /home/pepe/video/
    * @ param video_bitrate (int) Bitrate del video original
    * @param audio_bitrate (int) Bitrate de audio original
    * @param duration (int) Duración del vídeo en segundos.
    * @param format (e_video_format) Formato del video. Es un enum.@see e_video_format
    * @param aspect (QString) Aspecto de relación de la pelicula, 16/9,4/3,etc
    * @param has_Subs (bool) true si tiene subs, false si no.
    * @param subsPath (QString) Ruta a los subtitulos, Ejemplo: /home/pepe/video/video.srt
    * @param subsFont (QString) Fuente a utilizar para los subtitulos, Ejemplo: FreeMono.ttf, etc.
    * @param subsScale (int) Escala de los subtitulos, este valor es proporcional a la diagonal de
                                aspecto de la pelicula, y está entre 1 y 10.
    */
   Video_Item::Video_Item( QString filename,
                           QString filepath,
                           int video_bitrate,
                           int audio_bitrate,
                           int duration,
                           e_video_format format,
                           QString aspect,
                           bool has_Subs,
                           QString subsPath,
                           QString subsFont,
                           int subsScale)
   {
      m_video_filename = filename;
      m_video_path = filepath;
      m_video_bitrate = video_bitrate;
      m_audio_bitrate = audio_bitrate;
      m_video_duration = duration;

      m_subtitles_font = subsFont;
      m_subtitles = subsPath;
      m_subtitles_scale = subsScale;

      m_video_aspect = aspect;
      m_has_Subtitles = has_Subs;
      m_format = format;
      m_command = "";
      m_video_width = 0;
      m_video_height = 0;
      m_video_height_original = 0;
      m_video_width_original = 0;
      m_fps = 0;
      if(format== vcd)
         m_resolution = 1;
      else if(format ==  svcd)
         m_resolution = 2;
      else if(format == dvd)
         m_resolution = 3;
      else
         m_resolution = 0;
   }
   /**
     * Destructor de la clase
     */
   Video_Item::~Video_Item()
   {
   }

   /**
    * Permite asignar el nombre de archivo del video.
    * Ejemplo: video.avi
    * @param filename (QString) Nombre de archivo de video
    */
   void Video_Item::set_Video_Filename( QString filename )
   {
      m_video_filename = filename;
   }

   /**
    * Permite asignar la ruta al archivo del video.
    * Ejemplo: /home/pepe/video/
    * @param filepath (QString) Ruta al archivo de video
    */
   void Video_Item::set_Video_Path( QString filepath )
   {
      m_video_path = filepath;
   }

   /**
    * Permite asignar el bitrate de audio
    * @param audio_bitrate (int) Bitrate de Audio
    */
   void Video_Item::set_Audio_Bitrate( int audio_bitrate )
   {
      m_audio_bitrate = audio_bitrate;
   }

   /**
    * Permite asignar el bitrate de video
    * @param video_bitrate (int) Bitrate de Video
    */
   void Video_Item::set_Video_Bitrate( int video_bitrate )
   {
      m_video_bitrate = video_bitrate;
   }

   /**
    * Permite asignar la duracion del video en segundos
    * @param duration (int) Duracion en segundos.
    */
   void Video_Item::set_Video_Duration( int duration )
   {
      m_video_duration = duration;
   }

   /**
    * Permite asignar la fuente a utilizar para los subtitulos
    * @param font (QString) Fuente a usar.
    */
   void Video_Item::set_Subtitles_Font( QString font )
   {
      m_subtitles_font = font;
   }

   /**
    * Permite asignar la ruta a los subtitulos. Ejemplo: /home/pepe/video.srt
    * @param subtitles (QString) Ruta a los subtitulos.
    */
   void Video_Item::set_Subtitles_File( QString subtitles )
   {
      m_subtitles = subtitles;
   }

   /**
    * Permite establecer el tamanno de los subtitulos.
    * Esta escala es un valor entre 1 y 10, y se toma con
    * respecto a la diagonal del aspecto del video.
    * @param scale (int) Escala de los subtitulos.
    */
   void Video_Item::set_Subtitles_Scale( int scale )
   {
      m_subtitles_scale = scale;
   }

   /**
    * Permite asignar la relacion de aspecto del video 16/9, 4/3 o autoaspect.
    * @param vaspect (QString) Relacion de aspecto.
    */
   void Video_Item::set_Video_Aspect( QString vaspect )
   {
      m_video_aspect = vaspect;
   }

   /**
    * Retorna el nombre del archivo de video.
    * Ejemplo: pepe.avi
    * @return m_video_filename  (QString) Nombre del video.
    */
   QString Video_Item::get_Video_Name()
   {
      return m_video_filename;
   }

   /**
    * Retorna el nombre del archivo de video de salida,
    * es decir, el nombre que tendra el archivo final convertido.
    * Esto depende del tipo de proyecto, si se esta trabajando con
    * VCD seria [VCD]+nombre de archivo +"mpg".
    * Ejemplo: para un archivo de entrada pepe.avi quedaria
    * como archivo de salida [VCD]pepe.mpg
    *
    * @return  QString Nombre del archivo de salida.
    */
   QString Video_Item::get_Video_Output_Name()
   {
      QString output_name;
      QStringList word = get_Video_Name().split( "." );
      word.pop_back();
      output_name = word.join( "." );

      if ( m_format == vcd )
      {
         return "[VCD]" + output_name + ".mpg";
      }
      else
      {
         if( m_format == svcd )
         {
            return "[SVCD]" + output_name + ".mpg";
         }
         else
         {
            if( m_format == dvd )
            {
               return "[DVD]" + get_Video_Name() + ".mpg";
            }
            else
            {
               if( m_format == divx )
               {
                  return "[DivX]" + output_name + ".avi";
               }
               else
               {
                  if ( m_format == xvid )
                  {
                     return "[XVID]" + output_name + ".avi";
                  }
                  else
                  {
                     if( m_format == flv )
                     {
                        return "[FLV]" + output_name + ".flv";
                     }
                  }
               }
            }
         }
      }

      return "[UNKNOW]" + get_Video_Name();
   }

   /**
    * Retorna la relacion de aspecto del video.
    * @return m_video_aspect  (QString) Relacion de aspecto.
    */
   QString Video_Item::get_Video_Aspect()
   {
      return m_video_aspect;
   }

   /**
    * Retorna la ruta al archivo de video.
    * Ejemplo: /home/pepe/video/
    * @return m_video_path (QString) Ruta al video.
    */
   QString Video_Item::get_Video_Path()
   {
      return m_video_path;
   }

   /**
    * Retorna el bitrate de video
    * @return m_video_bitrate (int) Bitrate de video.
    */
   int Video_Item::get_Video_Bitrate()
   {
      return m_video_bitrate;
   }

   /**
    * Retorna el bitrate de audio
    * @return m_audio_bitrate (int) Bitrate de audio.
    */
   int Video_Item::get_Audio_Bitrate()
   {
      return m_audio_bitrate;
   }

   /**
    * Retorna el tamanno que ocupara el video convertido
    * de acuerdo al bitrate de video bitrate de audio establecidos y
    * la duracion en segundos del archivo de video.
    *
    * @return m_video_size (float) Tamanno que ocupara el video resultante.
    */
   float Video_Item::get_Video_Size()
   {
      m_video_size = ( m_video_bitrate + m_audio_bitrate ) * m_video_duration / 8388.608;
      return m_video_size;
   }

   /**
    * Retorna la duracion del video en segundos
    * @return m_video_duration (int) Duracion del video.
    */
   int Video_Item::get_Video_Duration()
   {
      return m_video_duration;
   }

   /**
    * Devuelve la escala de los subtitulos
    * La escala es un valor entre 1 y 10.
    *
    * @return m_subtitles_scale (int) Escala de los subtitulos.
    */
   int Video_Item::get_Subtitles_Scale()
   {
      return m_subtitles_scale;
   }

   /**
    * Retorna el comando para la conversion.
    * En este metodo se construye el comando con las opciones
    * especificas para el archivo de video que se va a convertir.
    * Tambien se tiene en cuenta el tipo de proyecto para las opciones
    * que se le pasan a MEncoder.
    *
    * @return m_command  (QString) Comando para mencoder.
    */
   QString Video_Item::get_Command()
   {
      //aqui en dependencia del formato
      // se construye el comando para el mplayer
      m_command = "";

      if ( m_format == vcd )
      {
         m_command += "-srate 44100 -af lavcresample=44100 -oac lavc -ovc lavc -of mpeg -mpegopts format=xvcd -ofps 30000/1001 -vf scale=";
         m_command += QString::number(get_Video_Width());
         m_command += ":";
         m_command += QString::number(get_Video_Height());
         m_command += ",harddup -lavcopts vcodec=mpeg1video:threads=2:trell:mbd=2:vstrict=0:vrc_maxrate=1152:vrc_buf_size=327:vrc_minrate=600:vbitrate=";
         m_command += QString::number( get_Video_Bitrate());
         m_command += ":acodec=mp2:abitrate=";
         m_command += QString::number( get_Audio_Bitrate() );
         m_command += m_video_aspect;
         m_command += " \"" + m_video_path + m_video_filename + "\"";
         //poner comando
      }
      else
      {
         if( m_format == svcd )
         {
            m_command  += " -srate 44100 -af lavcresample=44100 -oac lavc -ovc lavc -of mpeg -mpegopts format=xsvcd -ofps 30000/1001 -vf scale=";
            m_command += QString::number(get_Video_Width());
            m_command += ":";
            m_command += QString::number(get_Video_Height());
            m_command +=",harddup -lavcopts vcodec=mpeg2video:threads=2:trell:mbd=2:vstrict=0:vrc_maxrate=2500:vrc_buf_size=917:vrc_minrate=600:vbitrate=";
            m_command += QString::number( get_Video_Bitrate());
            m_command += ":acodec=mp2:abitrate=";
            m_command +=  QString::number( get_Audio_Bitrate() );
            m_command +=  m_video_aspect;
            m_command += " \"" + m_video_path + m_video_filename + "\"";
            //poner comando
         }
         else
         {
            if( m_format == dvd )
            {
               m_command += "\"" + m_video_path + m_video_filename + "\"";
               m_command += " -srate 48000 -af lavcresample=48000 -oac lavc -aid " ;
               m_command += QString::number(get_aid());
               m_command += " -ovc lavc -of mpeg -mpegopts format=dvd:tsaf";
               m_command += " -ofps 30000/1001 -vf scale=";
               m_command += QString::number(get_Video_Width());
               m_command += ":";
               m_command += QString::number(get_Video_Height());
               m_command += ",harddup -lavcopts";
               m_command += " vcodec=mpeg2video:threads=2:trell:mbd=2:vstrict=0:vrc_maxrate=9800:vrc_buf_size=1835:vbitrate=";
               m_command += QString::number( get_Video_Bitrate() );
               m_command += ":keyint=12:acodec=ac3:abitrate=";
               m_command += QString::number( get_Audio_Bitrate() ) ;
               m_command += m_video_aspect;
               //poner comando
            }
            else
            {
               if( m_format == divx )
               {
                  m_command += "-srate 44100 -af lavcresample=44100 -lavcopts vcodec=mpeg4:threads=2:trell:mbd=2:sc_threshold=1000000000:cgop:vbitrate=";
                  m_command += QString::number( get_Video_Bitrate() );
                  m_command += m_video_aspect;
                  m_command +=" -oac mp3lame -aid ";
                  m_command += QString::number(get_aid());
                  m_command += " -ofps 30000/1001  -ffourcc DX50 -ovc lavc -vf scale=";
                  m_command += QString::number(get_Video_Width());
                  m_command += ":";
                  m_command += QString::number(get_Video_Height());
                  m_command += ",harddup  -lameopts abr:br=";
                  m_command += QString::number( get_Audio_Bitrate() ) ;
                  m_command += " \"" + m_video_path + m_video_filename + "\"";
               }
               else
               {
                  if( m_format == xvid )
                  {
                     m_command += "-srate 44100 -af lavcresample=44100 -xvidencopts trellis:bitrate=";
                     m_command += QString::number( get_Video_Bitrate() );
                     m_command += m_video_aspect;
                     m_command +=" -oac mp3lame -aid ";
                     m_command += QString::number(get_aid());
                     m_command += " -ofps 30000/1001 -ffourcc XVID -ovc xvid -vf scale=";
                     m_command += QString::number(get_Video_Width());
                     m_command += ":";
                     m_command += QString::number(get_Video_Height());
                     m_command += ",harddup  -lameopts abr:br=";
                     m_command += QString::number( get_Audio_Bitrate() ) ;
                     m_command += " \"" + m_video_path + m_video_filename + "\"";
                  }
                  else
                  {
                     if( m_format == flv )
                     {
                        m_command += " \"" + m_video_path + m_video_filename + "\"";
                        m_command += " -of lavf -oac mp3lame -lameopts abr:br=";
                        m_command += QString::number( get_Audio_Bitrate() ) ;
                        m_command += " -ovc lavc -lavcopts vcodec=flv:vbitrate=";
                        m_command += QString::number( get_Video_Bitrate() );
                        m_command += ":mbd=2:mv0:trell:v4mv:cbp:last_pred=3";
                        m_command += " -srate 22050 -ofps 24 -vf scale=";
                        m_command += QString::number(get_Video_Width());
                        m_command += ":";
                        m_command += QString::number(get_Video_Height());
                        m_command += ",harddup";
                     }
                     else
                     {
                        return "Formato Indefinido";
                     }
                  }
               }
            }
         }
      }

      if( has_Subtitles() )
      {
         m_command += " -sub ";
         m_command += "\"";
         m_command += m_subtitles;
         m_command += "\"";
         m_command += " -subcp latin1 ";
         m_command += "-font ";
         m_command += m_subtitles_font;
         m_command += " -subfont-text-scale ";
         m_command += QString::number( m_subtitles_scale );
      }

      return m_command;
   }

   /**
    * Permite asignar true o false a la variable m_has_Subtitles.
    * Si se desea que el archivo tenga subs y que se incluyan en el comando
    * del MEncoder, es preciso poner esta variable en true. Si se pone en
    * false son ignorados los subtitulos.
    *
    * @param value (bool) Valor de la variable, true si tiene subtitulos, false si no.
    */
   void Video_Item::set_Has_Subtitles( bool value )
   {
      m_has_Subtitles = value;
   }

   /**
    * Devuelve true si el video tiene subtitulos, false si no.
    *
    * @return m_has_Subtitles (bool)
    */
   bool Video_Item::has_Subtitles()
   {
      return m_has_Subtitles;
   }

   /**
    * Retorna la ruta al archivo de subtitulos.
    * Ejemplo /home/pepe/video/video.srt
    *
    * @return m_subtitles (QString) Ruta a los subtitulos.
    */
   QString Video_Item::get_Subtitles_File()
   {
      return m_subtitles;
   }

   /**
    * Retorna la fuente a utilizar para los subtitulos (FreeMono, etc)
    *
    * @return m_subtitles_font (QString) Fuente para los subtitulos.
    */
   QString Video_Item::get_Subtitles_Font()
   {
      return m_subtitles_font;
   }

   /**
    * Este metodo permite establecer el tipo de proyecto al que
    * pertenece el archivo de video, o sea, si se va a crear un VCD, DVD o DivX,
    * entre otros. Recibe como argumento el enum e_video_format.
    *
    * @param format (e_video_format) Formato a convertir el video.
    * @see e_video_format
    */
   void Video_Item::set_Format( e_video_format format )
   {
      m_format = format;
   }

   /**
    * Devuelve el formato establecido para el archivo de video.
    * Este formato es un enum e_video_format, por lo que puede ser VCD, DVD, etc.
    *
    * @return m_format;
    * @see e_video_format
    */
   e_video_format Video_Item::get_Format()
   {
      return m_format;
   }

   /**
    * Metodo que me devuelve la estructura basica de un video en formato xml.
    * Traduce toda la informacion del elemento de video a una estructura XML.
    *
    * @return xml (QString) Un XML con toda la info del elemtento de video actual.
    */
   QString Video_Item::toXML()
   {
      QString xml = "";
      xml += "<video path=\"" + m_video_path + "\" filename=\"" + m_video_filename + "\">\n";
      xml += "<bitrate video=\""+ QString::number( m_video_bitrate ) + "\" audio=\"" + QString::number( m_audio_bitrate ) + "\"/>\n";
      xml += "<aspect value=\"" + m_video_aspect + "\"/>\n";
      xml += "<duration value=\"" + QString::number( m_video_duration ) + "\"/>\n";
      xml += "<fps fps=\"" + QString::number(m_fps) +"\"/>\n";
      xml += "<resolution resolution=\""+ QString::number(m_resolution) +"\" width=\""+ QString::number(m_video_width) +"\" height=\""+ QString::number(m_video_height) ;
      xml += "\" woriginal=\""+ QString::number(m_video_width_original) + "\" horiginal=\"" +QString::number(m_video_height_original) + "\"/>\n";
      xml += "<aid value=\"" + QString::number(m_aid) + "\"/>\n";


      if( m_has_Subtitles )
      {
         xml += "<subtitles path=\"" + m_subtitles + "\" font=\"" + m_subtitles_font + "\" scale=\"" + QString::number( m_subtitles_scale ) + "\"/>\n";
      }

      xml += "</video>\n";

      return xml;
   }

   /**
    * Este metodo permite establecer el ancho del video (WIDTH)
    * Recibe como argumento un int .
    *
    * @param video_width (int) Ancho del Video
    */
   void Video_Item::set_Video_Width(int video_width)
   {
      m_video_width = video_width;
   }

  /**
    * Este metodo permite establecer el id del flujo de audio (AID)
    * Recibe como argumento un int .
    *
    * @param aid (int) Canal de sonido
    */
   void Video_Item::set_aid(int aid)
   {
     m_aid = aid;
   }

   /**
    * Este metodo permite establecer el alto del video (HEIGHT)
    * Recibe como argumento un int .
    *
    * @param video_height (int) Alto del Video
    */
   void Video_Item::set_Video_Height(int height)
   {
      m_video_height = height;
   }

   /**
    * Este metodo permite establecer el los frames por segundos del video (FPS)
    * Recibe como argumento un float
    *
    * @param fps (float) frames por segundos
    */
   void Video_Item::set_Fps(float fps)
   {
      m_fps = fps;
   }

   /**
    * Devuelve el ancho del Video.
    *
    * @return m_video_width (int) Ancho del video
    */
   int Video_Item::get_Video_Width()
   {
      return m_video_width;
   }

   /**
    * Devuelve el alto del Video.
    *
    * @return m_video_height (int) Alto del video
    */
   int Video_Item::get_Video_Height()
   {
      return m_video_height;
   }

   /**
    * Devuelve los frames por segundo del Video.
    *
    * @return m_fps (float) Frames por segundos
    */
   float Video_Item::get_Fps()
   {
      return m_fps;
   }


   /**
    * Este metodo permite establecer el ancho original del video (HEIGHT)
    * Recibe como argumento un int .
    * Es necesario para tener una referencia a los valores originales
    * del video en caso de que el usuario los modifique y luego quiera
    * volver a los originales.
    *
    * @param video_width (int) Ancho del Video Original
    */
   void Video_Item::set_Video_Width_Original(int video_width)
   {
      m_video_width_original = video_width;
   }

   /**
    * Este metodo permite establecer el alto original del video (HEIGHT)
    * Recibe como argumento un int .
    * Es necesario para tener una referencia a los valores originales
    * del video en caso de que el usuario los modifique y luego quiera
    * volver a los originales.
    *
    * @param video_height (int) alto del Video Original
    */
   void Video_Item::set_Video_Height_Original(int video_height)
   {
      m_video_height_original = video_height;
   }


   /**
    * Devuelve el ancho original del Video.
    *
    * @return m_video_width_original (int) Ancho Original del video
    */
   int Video_Item::get_Video_Width_Original()
   {
      return m_video_width_original;
   }

   /**
    * Devuelve el alto del Video.
    *
    * @return m_video_height_original (int) Alto original del video
    */
   int Video_Item::get_Video_Height_Original()
   {
      return m_video_height_original;
   }
   /**
* Este metodo es creado por conveniencia.
* para actualizar el tipo de resolucion que tiene
* el video.
*
* @param resolution (int) Un valor entre 0 y 3
* 0 : Resolucion Original
* 1 : 352x240
* 2 : 480x480
* 3 : 720x480
*
* Este valor se guarda para no estar verificando
* a la hora de mostrar en la ventana de opciones
* la resolucion que tiene el video.
*/
   void Video_Item::set_Video_Resolution(int resolution)
   {
      m_resolution = resolution;

   }

   /**
* Devuelve la resolucion del video.
* @return resolution (int) Un valor entre 0 y 3
* 0 : Resolucion Original
* 1 : 352x240
* 2 : 480x480
* 3 : 720x480
*
*/
   int Video_Item::get_Video_Resolution()
   {
      return m_resolution;
   }

    /**
    * Devuelve el id del canal de audio del Video.
    *
    * @return m_aid (int) ID del canal de audio
    */
   int Video_Item::get_aid()
   {
    return m_aid;
   }

   /**
  * Funcion para actualizar loss atributos varibles del item
  * llamada cuando se selecciona Aplicar a todos
  */
   void Video_Item::Update(int vbitrate, int abitrate, QString aspect,
                           QString sFont, int sScale,
                           float fps, int resolution, int w, int h)
   {

      m_video_bitrate = vbitrate;
      m_audio_bitrate = abitrate;

      m_subtitles_font = sFont;
      m_subtitles_scale = sScale;

      m_video_aspect = aspect;
      if(resolution != 0)
      {
         m_video_width = w;
         m_video_height = h;
      }
      else
      {
         m_video_width = m_video_width_original;
         m_video_height = m_video_height_original;
      }
      m_fps = fps;
      m_resolution = resolution;
   }



   //ending namespace video
}
